osx_write.c: Use realloc() instead of free() and malloc()
[paraslash.git] / server.h
index fe6d858199c97a5a27ed586b76a6c8078840ad63..9d18561e0f8e1eb20300759cc597970795abe887 100644 (file)
--- a/server.h
+++ b/server.h
@@ -21,7 +21,7 @@
 #include "para.h"
 
 
/** size of the dbinfo and audio_file info strings of struct misc_meta_data */
 #define MMD_INFO_SIZE 16384
 
 /**
@@ -51,17 +51,17 @@ struct user{
  */
 struct server_command {
 /** the name of the command */
-       char *name;
+       const char *name;
 /** pointer to the function that handles the command */
        int (*handler)(int, int, char **);
 /** the privileges a user must have to execute this command */
        unsigned int perms;
 /** one-line description of the command */
-       char *description;
+       const char *description;
 /** summary of the command line options */
-       char *synopsis;
+       const char *synopsis;
 /** the long help text */
-       char *help;
+       const char *help;
 };
 
 /** holds the arguments for the para_server's sender command */
@@ -139,16 +139,17 @@ struct misc_meta_data{
        unsigned int active_connections;
 /** the process id of para_server */
        pid_t server_pid;
-/** a string that gets filled in by the current database tool */
-       char dbinfo[MMD_INFO_SIZE];
-/** the number if the current database tool */
-       int dbt_num;
-/** commands set this to non-zero to request a database tool change */
-       int dbt_change;
+/** a string that gets filled in by the current audio file selector */
+       char selector_info[MMD_INFO_SIZE];
+/** the number if the current audio file selector */
+       int selector_num;
+/** commands set this to non-zero to change the current selector */
+       int selector_change;
 /** used by the sender command */
        struct sender_command_data sender_cmd_data;
 };
 
+extern struct server_args_info conf;
 
 int handle_connect(int fd, struct sockaddr_in *addr);
 void mmd_unlock(void);
@@ -21,7 +21,7 @@
 
 
-/** size of the dbinfo and audio_file info strings of struct misc_meta_data */
+/** size of the selector_info and audio_file info strings of struct misc_meta_data */
 #define MMD_INFO_SIZE 16384
 